<?php
/*
 * Plugin Name: CSS Accordion
 * Version: 2.03
 * Plugin URI: https://nhws.localinfo.jp/
 * Description: Adds an accordion-like stretching effect. Write tags like [accordion label="abc" group="xyz" opened]contents[/accordion]
 * Author: NORTH HILL WORK STUDIO
 * Author URI: https://nhws.localinfo.jp/
 * Changelog:
 * v2.02:		*Fixed* Element style not allowed as child of element div in this context.
 * 				*Fixed* HTTP ERROR 500 under fp-1.3.dev.
 * Change-Date:	28.12.2022, by Fraenkiman
 * 
 * v2.01:		added open/close speed specification function
 * Change-Date:	27.12.2022, by Pea@West Tokyo/ NORTH HILL WORK STUDIO
 * 
 * v1.03:		Template-file ready for fp-1.3/ smarty 4
 * 				added german and italian translation
 * Change-Date:	26.12.2022, by Fraenkiman
 * 
 * v1.02: 		*Fixed* (pointed out by Arvid), allow some tags.
 * Change-Date:	18.12.2022, by Pea@West Tokyo/ NORTH HILL WORK STUDIO
 */


add_filter('init', 'plugin_bbcode_cssaccordion');
add_action('wp_head', 'plugin_accordion_head');


function plugin_bbcode_cssaccordion() {
	$bbcode = plugin_bbcode_init(); // import the "global" bbcode object into current function
									// this way 
									// a) parsing is done only once, and by the official plugin
									// b) you create only ONE object, and therefore computation is quicker
	$bbcode->addCode (
		'accordion',  // tag name: this will go between square brackets
		'callback_replace', // type of action: we'll use a callback function
		'plugin_custombbcode_accordion', // name of the callback function
		array ('usecontent_param' => array ('default')), // supported parameters: "default" is [inc=valore]
		'inline', // type of the tag, inline or block, etc
		array ('listitem', 'block', 'inline', 'link'), // type of elements in which you can use this tag
		array ()); // type of elements where this tag CAN'T go (in this case, none, so it can go everywhere)
	$bbcode->setCodeFlag('accordion', 'closetag', BBCODE_CLOSETAG_MUSTEXIST); // a closing tag is mandatory [/tag]
}


function plugin_custombbcode_accordion($action, $attributes, $content, $params, $node_object) {
	$accordionconf = plugin_getoptions('cssaccordion');	// Readout of settings
	$lang = lang_load('plugin:cssaccordion'); // multilingual support
	$accordion ['label'] = isset($attributes ['label']) ? htmlentities($attributes ['label']) : (
		isset($accordionconf ['label']) ? $accordionconf ['label'] : $lang ['plugin'] ['accordion'] ['label']
	);
	$accordiontype = isset($attributes ['group']) ?
		 'type="radio" name="' . $attributes ['group'] . '"' : 'type="checkbox"';
	$accordionid = uniqid();
	$allowed_tags = ['a','b','br','em','hr','i','img','li','ol','p','s','span','strong','u','ul'];
	$accordionchecked = isset($attributes ['opened']) ? ' checked' : '';
	return '<div><input id="' . $accordionid . '" class="ac-toggle"' . $accordiontype . $accordionchecked . '>' . '<label class="ac-title" for="' . $accordionid . '"><a>' . $accordion ['label'] . '</a></label>' . '<div class="ac-content">'.strip_tags($content ?? '', $allowed_tags) . '</div></div>';
}


function plugin_accordion_head() {
	$accordionconf = plugin_getoptions('cssaccordion');	// Readout of settings
	$delay = isset($accordionconf ['delay']) ? $accordionconf ['delay'] : 15;
	$pdir = plugin_geturl('cssaccordion');
	echo '
	<!-- start of NHWS CSS Accordion -->
	<link rel="stylesheet" type="text/css" href="' . $pdir . 'res/css_accordion.css.php?delay=' . $delay . '">
	<script src="' . $pdir . 'res/css_accordion.js"></script>
	<!-- end of NHWS CSS Accordion -->
	';
}


if (class_exists('AdminPanelAction')){
	/*
	 * Provides an admin panel entry for CSS Accordion setup.
	 */
	class admin_plugin_cssaccordion extends AdminPanelAction {
		/*
		 * Initializes this panel.
		 */
		function setup() {
			$this->smarty->assign('pluginurl', plugin_geturl('cssaccordion')); // for CSS file path in the template
			$this->smarty->assign('admin_resource', "plugin:cssaccordion/admin.plugin.cssaccordion");
		}
		/*
		 * Setups the default panel.
		 */
		function main() {
			$accordionconf = plugin_getoptions('cssaccordion');	// Readout of settings
			$lang = lang_load('plugin:cssaccordion'); // multilingual support
			$accordionconf ['label'] =
			 isset($accordionconf ['label']) ? $accordionconf ['label'] : $lang ['plugin'] ['accordion'] ['label'];
			$accordionconf ['delay'] =
			 isset($accordionconf ['delay']) ? $accordionconf ['delay'] : 15;
			$this->smarty->assign('accordionconf', $accordionconf);
		}
		/*
		 * Will be executed when the FontSizeSelect configuration is send.
		 * @return int
		 */
		function onsubmit($data = null) {
			global $fp_config;
			if ($_POST['label'] && $_POST['delay']) {
				if ($_POST['delay'] < 5 || $_POST['delay'] > 50){
					$_POST['delay'] = 15;
				}
				plugin_addoption('cssaccordion', 'label', htmlentities($_POST['label']));
				plugin_addoption('cssaccordion', 'delay', htmlentities($_POST['delay']));
				plugin_saveoptions('cssaccordion');
				$this->smarty->assign('success', 1);
			} else {
				$this->smarty->assign('success', -1);
			}
			return 2;
		}
	}
	admin_addpanelaction('plugin', 'cssaccordion', true);
}

?>
